@@ -45,7 +45,7 @@ UNARY_ASSIGNERS = {
     "sqrt": "sqrt",
     "rand": "rand",
     # Custom assigners
-    "=~": "not",
+    "~": "not",
     "ln": "log",
     "lg": "log10"
 }
@@ -58,8 +58,10 @@ def extended_let(src_line: str) -> list:
     xlet a1 = b + c
     xlet a1 = 2 ** 8
     xlet a2 min c d
+    xlet a2 =min c d
     xlet a2 =~ x
     xlet a2 floor x
+    xlet x =sensor @unit @x
     """
     verdicts = src_line.split()
     if len(verdicts) == 2:
@@ -73,6 +75,8 @@ def extended_let(src_line: str) -> list:
             output_verdicts.append(verdicts[3])
             line = " ".join(output_verdicts)
             return [line, ]
+
+        verdicts[2] = verdicts[2].lstrip("=")
         if verdicts[2] in UNARY_ASSIGNERS.keys():
             vanilla_assigner = UNARY_ASSIGNERS[verdicts[2]]
             output_verdicts.append("op")
@@ -84,7 +88,7 @@ def extended_let(src_line: str) -> list:
             return [line, ]
 
         message = F"error: unsupported operator '{verdicts[2]}'"
-        if verdicts[2] in BINARY_ASSIGNERS[verdicts[2]]:
+        if verdicts[2] in BINARY_ASSIGNERS.keys():
             message = F"error: too few argument for '{verdicts[2]}'"
         raise CompilationError(message)
 
@@ -99,6 +103,14 @@ def extended_let(src_line: str) -> list:
             output_verdicts.append(verdicts[4])
             line = " ".join(output_verdicts)
             return [line, ]
+        # Use sensor command
+        verdicts[2] = verdicts[2].lstrip("=")
+        if verdicts[2] == "sensor":
+            output_verdicts.append("sensor")
+            output_verdicts.append(verdicts[1])
+            output_verdicts.extend(verdicts[3:5])
+            line = " ".join(output_verdicts)
+            return [line, ]
         message = F"error: unsupported operator '{verdicts[2]}'"
         raise CompilationError(message)
 
